\name{stacd.data}
\alias{stacd.data}
\concept{data generation}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Generate data under STACD model
}
\description{
Generates data following the STACD model with the specified model parameters. The phenotype may be generated based on existing genotypes, or genotype data can be generated.
}
\usage{
stacd.data(betas, x = NULL, z = NULL, n = NULL,
        ncase=NULL, ncontrol=NULL, pa = NULL, pb = NULL, 
        model = "logistic", ve = NULL, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{betas}{
a length 9 numeric vector of the STACD model parameters (in order: \emph{mu}, \emph{alpha_1}, \emph{alpha_2}, \emph{beta_1}, \emph{beta2}, \emph{gamma_ab}, \emph{gamma^*_aab}, \emph{gamma^*_abb}, and \emph{gamma^*_aabb})
}
  \item{x}{
a numeric vector of genotype data at the first locus, coded 0,1,2 for the number of reference alleles.
}
  \item{z}{
data for the second locus, as \code{x}
}
  \item{n}{
sample size for the generated data. Ignored with a warning if data is provided for \code{x} and/or \code{z}.
}
  \item{ncase}{
number of affected individuals to include in the generated data. Only applicable to the \"logistic\" model. Ignored with a warning if data is provided for \code{x} and/or \code{z}.
}
  \item{ncontrol}{
number of unaffected individuals to include in the generated data. Only applicable to the \"logistic\" model. Ignored with a warning if data is provided for \code{x} and/or \code{z}.
}
  \item{pa}{
allele frequncy for the first locus. Ignored with a warning if \code{x} is given.
}
  \item{pb}{
allele frequency for the second locus. Ignored with a warning if \code{z} is given.
}
  \item{model}{
either "normal" or "logistic", specifying the scale of the STACD model. If "normal", then the phenotype is continuous with normally distributed errors. If "logistic", then the phenotype is dichotomous based on an underlying continuous variable with logistically distributed errors.
}
  \item{ve}{
The variance of the error term in the normal model. If not specified, it will be set so that the total phenotypic variance is 1. If model="logistic", this argument is ignored (with a warning).
}
  \item{verbose}{
Logical, indicating whether to provide additional information about the model. Default is FALSE.
}
}
\details{
Data may be generated based on existing genotype data (coded 0,1,2 or NA), or new genotype data may be generated from \emph{Bin(2,p)}. If existing genotype data is provided for \code{x} and \code{z} then the sample size \code{n} and allele frequencies \code{pa} and \code{pb} are ignored. If no data is provided then the sample size and allele frequencies must be given so that new genotype data can be generated. For the logistic model, the sample size can optionally be specified to include a specific number of cases (\code{y=1}) and controls (\code{y=0}), instead of a simple random sample of size \code{n} from the population.

Optionally, by setting \code{verbose=TRUE} expected characteristics of the generated data will be provided in the format of \code{\link{stacd.model}}. If existing genotype data was used to generate the phenotype, these expected values and the variance decomposition are computed based on the observed allele frequencies in the input data.

The two loci for the genotype data are assumed to be biallelic, unlinked, and under Hardy-Weinberg equilibrium.
}
\value{
If \code{verbose=FALSE}, the function returns a data frame with columns \code{y}, \code{x}, and \code{z}, where \code{y} is the generated phenotype data and \code{x}, and \code{z} are either the provided genotype data or new generated genotypes.

If \code{verbose=TRUE}, more complete information is returned. The output will include:
\item{Full_Data}{data frame containing the full generated data, including latent values where applicable. Specifically,

\code{y} - the generated phenotype
\code{ystar} - (logistic model only) the latent continuous variable dichotomize to \code{y}
\code{XB} - the value of the linear model minus the error term
\code{yprob} - (logistic model only) the probability \code{y=1} conditional on the genotypes
\code{x} - genotype data for the first locus
\code{z} - genotype data for the second locus
}
\item{Model_Info}{Expected values and variance decomposition for the model. If existing genotype data was used for \code{x} or \code{z}, model information is computed based on the observed allele frequency in the data. If a fixed number of cases and controls were generated, this information reflects the population from which the individuals were sampled, not expected sample statistics. See \code{\link{stacd.model}} for details on the provided information.}
}
\references{
Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.
}
\author{
Raymond Walters
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{stacd.model}}
}
\examples{
# Example from Walters et al:
exparams <- varex.to.stacd(varex=rep(0.05,8), pa=0.3, pb=0.3, 
                           model="logistic", decomp="parameter", 
                           mu=0, ve=0.6)
data5k <- stacd.data(betas=exparams$Betas, n=5000, 
                     pa=0.3, pb=0.3, model="logistic")
head(data5k)

# generate data from existing genotypes
x <- rbinom(100,2,.5)
z <- rbinom(100,2,.3)
betas <- c(0,0,0,0,0,0,.25,0,.5)
dat.M <- stacd.data(betas,x,z)
head(dat.M)

# extra model output
mod3 <- stacd.data(betas,n=100,pa=.3,pb=.5,verbose=TRUE)
dat3.M <- mod3$Full_Data
head(dat3.M)
mod3$Model_Info
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ datagen }
\keyword{ models }
