\name{varex.to.stacd}
\alias{varex.to.stacd}
\concept{variance decomposition}
\concept{convert models}
\title{
Convert variance decomposition to STACD parameters
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
Convert variance decomposition to STACD parameters
}
\usage{
varex.to.stacd(varex, pa, pb, model = "logistic", 
        decomp = "cockerham", mu = NA, ve = NA, 
        sign = rep(1, 8))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{varex}{
an 8 element vector of non-negative values with sum < 1. The meaning of these values depends on \code{decomp} (see Details).
}
  \item{pa}{
allele frequency for the first locus
}
  \item{pb}{
allele frequency for the second locus
}
  \item{model}{
either "normal" or "logistic" specifying the scale of the STACD model. If "normal", then the phenotype is continuous with normally distributed errors. If "logistic", then the phenotype is dichotomous based on a latent continuous variable with logistically distributed errors.
}
  \item{decomp}{
a string specifying either the "parameter" or "cockerham" variance decomposition (see Details)
}
  \item{mu}{
The mu parameter for the STACD model. It does not affect the variance decomposition so can be specified separately. By default set so that \code{E(y)=0} for the normal model or \code{E(ystar)=0} for the logistic model.
}
  \item{ve}{
The variance of the error term in the normal model. If not specified for the normal model, \code{ve} will be set so that the total phenotypic variance is 1. This argument is ignored  for the logistic model (with a warning).
}
  \item{sign}{
a length 8 vector with elements 1 or -1 denoting the sign of the square root to use with each variance component. By default, all positive square roots are used. See Details.
}
}
\details{
The STACD model parameters are computed based on the provided variance decomposition and allele frequencies. For the "parameter" decomposition, the elements of \code{varex} are taken to be the semipartial correlation of the corresponding STACD parameter conditional on all lower order effects, i.e.

\code{varex} = \emph{(R^2_{alpha_1}, R^2_{alpha_2|alpha_1}, 
        R^2_{beta_1}, R^2_{beta_2|beta_1}, 
        R^2_{gamma_ab|alpha_1,alpha_2,beta_1,beta_2}, 
        R^2_{gamma^*_aab|alpha_1,alpha_2,beta_1,beta_2,gamma_ab}, 
        R^2_{gamma^*_abb|alpha_1,alpha_2,beta_1,beta_2,gamma_ab},
        R^2_{gamma^*_aabb|alpha_1,alpha_2,beta_1,beta_2,gamma_ab,gamma_aab^*,gamma_abb^*})}

For the "cockerham" decomposition, the elements of \code{varex} instead correspond to the additive, dominant, and interaction variance components defined by Cockerham (1954), i.e.

\code{varex} = \emph{(V_addA,V_domA,V_addB,V_domB,
        V_addxadd,V_addAxdomB,V_domAxaddB,V_domxdom)/Vary}

In either case, the the variance decomposition does not determine the value of \code{mu}, so it needs to be set separatly. For the logistic model, adjusting \code{mu} helps control the prevalence.

For the logistic model, the variance decomposition is applied following the approach of McKelvey & Zavoina to parition the variance of a continuous latent variable with logistically-distributed errors that is then dichotomized to the observed phenotype.

In addition to the STACD parameters, additional model information is provided using the same format as \code{\link{stacd.model}}. This information includes conditional and marginal expected values, and both variance decompositions.

Since the STACD parameters are a function of the square root of the variance components they are not uniquely defined. Instead it is necessary to decide whether to use the positive or the negative square root of each variance component. The \code{sign} argument is a vector with elements 1 or -1 to specify which square root to use for each variance component. By default, the positive root is used for all components. 
}
\value{
\item{Betas}{STACD model parameters}
\item{Variance_Explained}{a list with elements:

\code{Multiple_R_Sq} - total proportion of variance explained by ther model
 
\code{Parameter_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the STACD paramters

\code{Cockerham_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the conventional decomposition given by Cockerham (1954).}

In addition, information about the conditional expected values and error variance the phenotype is computed. The format for this information depends on whether the "normal" or "logistic" model is specified. For the logistic model, the ouput includes

\item{Penetrances}{the provided 3x3 penetrance matrix}
\item{Marginals}{length 3 vectors of the marginal pentrance conditional on the first locus and on the second locus}
\item{Prevalence}{expected prevalence of the dichotmoous phenotype}
\item{Var_ystar}{variance of the continuous variable underlying the phenotype}

For the normal model, the output instead includes

\item{Expected_Values}{a list with elements:

\code{Conditional} - a 3x3 matrix of the expected value of the phenotype by genotype

\code{MarginA} - length 3 vector of the marginal expected value conditional on the genotype of the first locus

\code{MarginB} - length 3 vector of the marginal expected value conditional on the genotype of the second locus

\code{Unconditional} - overall expected value of the phenotype}
\item{Var_y}{expected variance of the phenotype}
\item{error_variance}{variance of the (normally-distrbuted) error term for the phenotype}
}
\references{
Cockerham, C. C. (1954). An extension of the concept of partitioning hereditary variance for analysis of covariance among relatives when epistasis is present. \emph{Genetics}, 39: 859-882.

McKelvey, R., and Zavoina, W. (1975). A Statistical model for the analysis of ordinal level dependent variables. \emph{Journal of Mathematical Sociology}, 4: 103-120.

Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.}
\author{
Raymond Walters
}
\note{
Since the STACD parameters are not uniquely defined by the variance components, the results of \code{varex.to.stacd} may not always exactly reverse \code{\link{stacd.model}}. In other words, if \code{\link{stacd.model}} is used to compute a variance decomposition, and \code{varex.to.stacd} is run with those variance components, \code{varex.to.stacd} is not guaranteed to reproduce the STACD parameters originally input into \code{\link{stacd.model}} (the STACD parameters can be reproduced with the correct setting for \code{sign}, but are not guaranteed by default). The variance components for the models will be equivalent, but the parmeters may differ.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
For variance decomposition of given STACD parameters, see \code{\link{stacd.model}}
}
\examples{
# Example from Walters et al
exparams <- varex.to.stacd(varex=rep(0.05,8), pa=0.3, pb=0.3, 
                           model="logistic", decomp="parameter", 
                           mu=0, ve=0.6)
print(exparams)

# additive effect of locus 1, 
# additive x additive interaction, and 
# dominant x dominant interaction
varex <- c(.003,0,0,0,.003,0,0,.003)
varex.to.stacd(varex, pa=.3, pb=.5)

# adjust prevalence
varex.to.stacd(varex, pa=.3, pb=.5, mu=-4)

# alternative parameters with same variance decomp
varex.to.stacd(varex, pa=.3, pb=.5, sign=c(rep(-1,4),rep(1,4)))

# alternative decomposition
varex.to.stacd(varex, pa=.3, pb=.5, decomp="parameter")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ models }
